(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8516,        251]*)
(*NotebookOutlinePosition[      9162,        273]*)
(*  CellTagsIndexPosition[      9118,        269]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Visualizing Earthquake Data", "Subtitle"],

Cell["\<\
USGS/NEIC (PDE) 1 Jan 2004 to 27 Jun 2005. 
Data from: http://neic.usgs.gov/neis/epic/epic_global.html\
\>", "Text"],

Cell["First, we import the data.", "Text"],

Cell[BoxData[
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\)], "Input"],

Cell[BoxData[
    \(\(data = Import["\<quake4.csv\>"];\)\)], "Input"],

Cell["\<\
Next, we construct a working dataset comprised of only the fields we are \
interested in.  In this case, the latitude, longitude, magnitude, and depth.  \
To expression is used here to force blank fields to become Null entries.\
\>", "Text"],

Cell[BoxData[
    \(\(newdata = 
        Table[ToExpression[{data[\([i, 5]\)], data[\([i, 6]\)], 
              data[\([i, 7]\)], data[\([i, 8]\)]}], {i, 1, 
            Length[data]}];\)\)], "Input"],

Cell["\<\
A few entries contain letters.  For the purposes here, we only want numeric \
entries.\
\>", "Text"],

Cell[BoxData[
    \(\(finaldata = 
        Cases[newdata, {lat_?NumericQ, lon_?NumericQ, mag_?NumericQ, 
            dep_?NumericQ}];\)\)], "Input"],

Cell[BoxData[
    \(Length[finaldata]\)], "Input"],

Cell["\<\
It is useful to overlay the data with the continents for geographic \
reference.  The WorldPlot package can be used here.\
\>", "Text"],

Cell[BoxData[
    \(<< Miscellaneous`WorldPlot`\)], "Input"],

Cell["\<\
We want to extract the Graphics primitives for later use.  For this reason, \
the WorldPlot object is converted into a Graphics object.\
\>", "Text"],

Cell[BoxData[
    \(initmap = 
      Graphics[WorldPlot[World, WorldGrid \[Rule] None, Axes \[Rule] False, 
          WorldFrame \[Rule] None]]\)], "Input"],

Cell["\<\
Here, we extract the polygons and convert them to Line primitives.  This way, \
we only see the outline of the continents and countries, rather than filled \
polygons that might block our view.\
\>", "Text"],

Cell[BoxData[
    \(\(unscaledmap = \((Cases[initmap[\([1]\)], Polygon[___], Infinity] /. 
            Polygon[x__] \[Rule] Line[x])\);\)\)], "Input"],

Cell[CellGroupData[{

Cell["2D", "Section"],

Cell["\<\
Now, we can start manipulating the data.  First, we replace and transform all \
4-tuples in the dataset into the appropriate Graphics directives and \
primitives.  This includes size and color values.   The PointSize is \
arbitrarily scaled for visual effect.\
\>", "Text"],

Cell[BoxData[
    \(\(grdata2D = 
        finaldata /. {lat_, lon_, mag_, 
              dep_} \[Rule] {PointSize[mag^2.7/6000], Hue[ .8 -  .8\ mag/10], 
              Point[{lon, lat}]};\)\)], "Input"],

Cell["\<\
The original map graphic needs to be rescaled so that all of the vertices \
conform to latitude and longitude ranges.  The following rescales every pair \
of points to the appropriate ranges.\
\>", "Text"],

Cell[BoxData[
    \(\(map2d = 
        unscaledmap /. {x_?NumberQ, 
              y_?NumberQ} \[Rule] {Rescale[
                x, {\(-11000\), 11000}, {\(-180\), 180}], 
              Rescale[y, {\(-5000\), 5000}, {\(-90\), 90}]};\)\)], "Input"],

Cell["\<\
Now, we can combine the map and the data.  The result visually demonstrates \
that most of the earthquakes occur along the continental plate boundaries.  \
Most of the quakes are blue or green and are small to medium in size.  Large \
quakes are less frequent, but this dataset includes at least two large \
quakes, including the destrcutive Sumatra earthquake that occurred in \
December of 2004.  Earthquakes are so common in this area that the \
predominance of the smaller quakes nearly obscures the location of the large \
quake shown as an orange spot.  Close examination also shows another large \
quake southeast of Australia.   \
\>", "Text"],

Cell[BoxData[
    \(myout2d = 
      Show[Graphics[{map2d, grdata2D}], ImageSize \[Rule] 600, 
        Frame \[Rule] True]\)], "Input"],

Cell["We can zoom in on an area of interest by using PlotRange.", "Text"],

Cell[BoxData[
    \(Show[Graphics[{map2d, grdata2D}], ImageSize \[Rule] 600, 
      PlotRange \[Rule] {{80, 180}, {\(-50\), 50}}, 
      AspectRatio \[Rule] 1]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3D", "Section"],

Cell["\<\
For a 3D visualization, we can perform similar operations as for the 2D case. \
 In this case, we transform the 2D map into a 3D map by transforming all of \
the point pairs into triples.  The z value is set to zero in all cases. \
\>", "Text"],

Cell[BoxData[
    \(\(map3d = 
        map2d /. {x_?NumberQ, y_?NumberQ} \[Rule] {x, y, 0};\)\)], "Input"],

Cell[BoxData[
    \(Show[Graphics3D[map3d], Axes \[Rule] True]\)], "Input"],

Cell["\<\
We also transform the data, just as we did in the 2D case.  However, this \
time we use 3D points and include the depth as the z value.\
\>", "Text"],

Cell[BoxData[
    \(\(grdata = 
        finaldata /. {lat_, lon_, mag_, 
              dep_} \[Rule] {PointSize[mag^2.5/6000], Hue[ .8 -  .8\ mag/10], 
              Point[{lon, lat, \(-dep\)}]};\)\)], "Input"],

Cell["\<\
We can combine the map and the data as we did in the 2D case.  However, we \
use only a subset of the data this time.  In this case, we only plot 10,000 \
of the data points.\
\>", "Text"],

Cell[BoxData[
    \(myout = 
      Show[Graphics3D[{Take[grdata, {20000, 30000}], map3d}], 
        ImageSize \[Rule] 800, BoxRatios \[Rule] {2, 1,  .5}, 
        TextStyle \[Rule] {"\<FontFamily\>" -> "\<Arial\>", 
            FontWeight -> "\<Bold\>"}, 
        PlotLabel \[Rule] 
          DisplayForm[
            GridBox[{{StyleForm["\<Earthquake Data\>", 
                    FontSize \[Rule] 
                      24]}, {StyleForm["\<Subset of Worldwide Data since 1 \
Jan 2004\>", FontSize \[Rule] 14, FontColor \[Rule] Gray]}}]], 
        Axes \[Rule] True]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Animation", "Section"],

Cell[BoxData[
    \(\(anim = 
        Table[Show[Graphics3D[{Take[grdata, {20000, 30000}], map3d}], 
            ImageSize \[Rule] 600, BoxRatios \[Rule] {2, 1,  .5}, 
            SphericalRegion \[Rule] True, 
            TextStyle \[Rule] {"\<FontFamily\>" -> "\<Arial\>", 
                FontWeight -> "\<Bold\>"}, 
            PlotLabel \[Rule] 
              DisplayForm[
                GridBox[{{StyleForm["\<Earthquake Data\>", 
                        FontSize \[Rule] 
                          24]}, {StyleForm["\<Subset of Worldwide Data since \
1 Jan 2004\>", FontSize \[Rule] 14, FontColor \[Rule] Gray]}}]], 
            Axes \[Rule] False, 
            ViewPoint \[Rule] {2\ Cos[t], 2\ Sin[t], 1}], {t, 0, 
            2\ \[Pi],  .05}];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
WindowSize->{1202, 740},
WindowMargins->{{31, Automatic}, {Automatic, 49}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 47, 0, 51, "Subtitle"],
Cell[1826, 55, 126, 3, 52, "Text"],
Cell[1955, 60, 42, 0, 33, "Text"],
Cell[2000, 62, 183, 4, 30, "Input"],
Cell[2186, 68, 69, 1, 30, "Input"],
Cell[2258, 71, 251, 4, 33, "Text"],
Cell[2512, 77, 200, 4, 30, "Input"],
Cell[2715, 83, 110, 3, 33, "Text"],
Cell[2828, 88, 148, 3, 30, "Input"],
Cell[2979, 93, 50, 1, 30, "Input"],
Cell[3032, 96, 145, 3, 33, "Text"],
Cell[3180, 101, 60, 1, 30, "Input"],
Cell[3243, 104, 159, 3, 33, "Text"],
Cell[3405, 109, 156, 3, 30, "Input"],
Cell[3564, 114, 217, 4, 33, "Text"],
Cell[3784, 120, 150, 2, 30, "Input"],

Cell[CellGroupData[{
Cell[3959, 126, 21, 0, 73, "Section"],
Cell[3983, 128, 283, 5, 52, "Text"],
Cell[4269, 135, 202, 4, 30, "Input"],
Cell[4474, 141, 215, 4, 33, "Text"],
Cell[4692, 147, 246, 5, 30, "Input"],
Cell[4941, 154, 661, 10, 71, "Text"],
Cell[5605, 166, 135, 3, 30, "Input"],
Cell[5743, 171, 73, 0, 33, "Text"],
Cell[5819, 173, 172, 3, 30, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6028, 181, 21, 0, 73, "Section"],
Cell[6052, 183, 254, 4, 33, "Text"],
Cell[6309, 189, 106, 2, 30, "Input"],
Cell[6418, 193, 75, 1, 30, "Input"],
Cell[6496, 196, 159, 3, 33, "Text"],
Cell[6658, 201, 210, 4, 30, "Input"],
Cell[6871, 207, 198, 4, 33, "Text"],
Cell[7072, 213, 580, 12, 130, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7689, 230, 28, 0, 73, "Section"],
Cell[7720, 232, 768, 15, 130, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

